@@ -563,6 +563,7 @@ async def teleportToInteractiveTeleportIfAvailable(p, currentZone, destinationZo
 async def read_control_checkbox_text(checkbox: Window) -> str:
     return await checkbox.read_wide_string_from_offset(616)
 
+
 @logger.catch()
 # trace back to the nearest spiral door and teleport to destinationWorld
 async def goToNewWorld(p, destinationWorld):
@@ -578,17 +579,13 @@ async def goToNewWorld(p, destinationWorld):
     # each worldList item (in-file name for a world) correlates to a zoneDoorOptions (in-file name for the buttons in the spiral door)
     worldList = ["WizardCity", "Krokotopia", "Marleybone", "MooShu", "DragonSpire", "Grizzleheim", "Celestia", "Wysteria", "Zafaria", "Avalon", "Azteca", "Khrysalis", "Polaris", "Arcanum", "Mirage", "Empyrea", "Karamelle", "Lemuria"]
     zoneDoorOptions = ["wbtnWizardCity", "wbtnKrokotopia", "wbtnMarleybone", "wbtnMooShu", "wbtnDragonSpire", "wbtnGrizzleheim", "wbtnCelestia", "wbtnWysteria", "wbtnZafaria", "wbtnAvalon", "wbtnAzteca", "wbtnKhrysalis", "wbtnPolaris", "wbtnArcanum", "wbtnMirage", "wbtnEmpyrea", "wbtnKaramelle", "wbtnLemuria"]
-    zoneDoorNameList = ["Wizard City", "Krokotopia", "Marleybone", "MooShu", "DragonSpire", "Grizzleheim", "Celestia", "Wysteria", "Zafaria", "Avalon", "Azteca", "Khrysalis", "Polaris", "Arcanum", "Mirage", "Empyrea", "Karamelle", "Lemuria"]
-    # user could be on any of the three pages when opening the world door depending on what their active quest is
-    # switch all the way to the first page to standardize it
-    for i in range(6):
-        await p.mouse_handler.click_window_with_name('leftButton')
-        await asyncio.sleep(0.2)
+    zoneDoorNameList = ["Wizard City", "Krokotopia", "Marleybone", "MooShu", "Dragonspyre", "Grizzleheim", "Celestia", "Wysteria", "Zafaria", "Avalon", "Azteca", "Khrysalis", "Polaris", "Arcanum", "Mirage", "Empyrea", "Karamelle", "Lemuria"]
 
     option_window = await p.root_window.get_windows_with_name("optionWindow")
 
     assert len(option_window) == 1, str(option_window)
 
+    # Get page count, current selected page number, and max page number
     for child in await option_window[0].children():
         if await child.name() == 'pageCount':
             pageCount = await child.maybe_text()
@@ -597,6 +594,8 @@ async def goToNewWorld(p, destinationWorld):
             maxPage = pageCount.split('/', 1)[1]
             break
 
+    # user could be on any of the three pages when opening the world door depending on what their active quest is
+    # switch all the way to the first page to standardize it
     # in case wizwalker misclicked / didn't click enough originally when resetting to page 1, ensure we are on page 1 (and if not click over again)
     while str(currentPage) != '1':
         await p.mouse_handler.click_window_with_name('leftButton')
@@ -766,8 +765,6 @@ async def goToDestination(p, destinationZone, p1WorldName, bigStackDestinations,
             currentZone = await p.zone_name()
 
 
-
-
     # for certain worlds, check if there is a teleporter between currentZone and destinationZone before traversing zones manually
     teleportedToZone = False
     if p1WorldName in ['Empyrea', 'Karamelle', 'Lemuria']:
@@ -968,20 +965,38 @@ async def goToDestination(p, destinationZone, p1WorldName, bigStackDestinations,
                     await teleportToInteractiveTeleportIfAvailable(p, zone, zoneTo, interactiveTeleportersOriginal)
 
 
-
-
 @logger.catch()
 async def toZoneDisplayName(clients, destinationZoneDisplay):
+    worldAbbreviations = ['WC', 'KT', 'MB', 'MS', 'DS', 'GH', 'CL', 'WT', 'ZF', 'AV', 'AZ', 'KR', 'PL', 'AC', 'MI', 'EM', 'KM', 'LM']
+    worldList = ["WizardCity", "Krokotopia", "Marleybone", "MooShu", "DragonSpire", "Grizzleheim", "Celestia",
+                 "Wysteria", "Zafaria", "Avalon", "Azteca", "Khrysalis", "Polaris", "Arcanum", "Mirage", "Empyrea",
+                 "Karamelle", "Lemuria"]
+
     file = open(f"{cur_path}/{'traversalData/displayZones.txt'}", "r")
     lines = file.readlines()
-
-    destinationZone = ''
     lines = iter(lines)
+    destinationZone = ''
+
+    # if specific world command was used, create a new list of zones only within the specified world
+    if any(destinationZoneDisplay.startswith(abbreviation + ' ') for abbreviation in worldAbbreviations):
+        abbrIndex = worldAbbreviations.index(abbreviation)
+        worldLines = []
+        world = worldList.index(abbrIndex)
+
+        for q, s in enumerate(lines):
+            split = s.split(';')
+            if split[1] == world:
+                worldLines.append(s)
+
+            lines = iter(worldLines)
+
+        destinationZoneDisplay = destinationZoneDisplay.split(abbreviation + ' ')[1]
+
     for q, s in enumerate(lines):
         s = s.split(';')
 
         # substring match instead of equality - it is acceptable for users to guess a partial zone name
-        if destinationZoneDisplay in s[2].strip():
+        if destinationZoneDisplay.lower() in s[2].lower().strip():
             destinationZone = s[1]
             break
 
